@@ -84,6 +84,24 @@ def build_argparser():
         'execute the instructions from the given file before starting the interactive session.'
     )
 
+    parser.add_argument(
+        "--show-regs",
+        action='store_true',
+        dest='show_regs',
+        required=False,
+        help=
+        'show the registers available for the given architecture/mode and quit.'
+    )
+
+    parser.add_argument(
+        "--timeout",
+        metavar='<secs>',
+        dest='timeout',
+        required=False,
+        default=5,
+        help='timeout for parsing and executing each assembly instruction.'
+    )
+
     parser.add_argument(
         '-V',
         '--version',
