@@ -5,11 +5,16 @@ from .cmdline import build_argparser
 from keystone import KsError
 from unicorn import UcError
 
+import sys
+import threading
+
 
 def main():
     parser = build_argparser()
     args = parser.parse_args()
 
+    args.timeout = max(int(args.timeout), 1)
+
     init_inputs = []
     if args.init_file:
         with open(args.init_file, 'rt') as f:
@@ -18,9 +23,13 @@ def main():
     # Initialize engines
     ks, mu, regs, pc, mem = get_engines(args.arch, args.mode)
 
+    if args.show_regs:
+        display_registers(regs, columns=5)
+        sys.exit(0)
+
     reg_globs = args.reg_globs
     if not reg_globs:
-        reg_globs = _supported_regs[args.arch][-1]
+        reg_globs = _supported_regs[args.arch][-2]
 
     visible_regs = list(select_registers(regs, reg_globs))
 
@@ -50,9 +59,26 @@ def main():
             code, comment = code_comment
 
             try:
-                instrs, _ = ks.asm(code, as_bytes=True)
+                ret = []
+
+                def parse_assembly():
+                    ret.extend(ks.asm(code, as_bytes=True))
+
+                th = threading.Thread(target=parse_assembly, daemon=True)
+                th.start()
+                th.join(args.timeout)
+
+                if not ret:
+                    raise TimeoutError()
+
+                instrs, _ = ret
                 if not instrs:
                     continue
+            except TimeoutError as e:
+                print(
+                    "Parse assebly timedout (possible Keystone bug/syntax error). Aborting."
+                )
+                sys.exit(1)
             except KsError as e:
                 print("Syntax error: %s" % e)
                 continue
@@ -66,7 +92,11 @@ def main():
 
             try:
                 # emulate code in infinite time & unlimited instructions
-                mu.emu_start(pc_addr, pc_addr + len(instrs))
+                mu.emu_start(
+                    pc_addr,
+                    pc_addr + len(instrs),
+                    timeout=args.timeout * 1000
+                )
             except UcError as e:
                 print("Execution error: %s" % e)
                 continue
